# KiiBlocks

## About this project
This project is designed to be a fully operational, open-source game for iOS based on the SpriteKit framework introduced in iOS7. 

Follow the videos below if it's your first time getting into SpriteKit for a full tutorial, or dive right into the code.

The game utilizes [Kii Cloud](http://en.kii.com/develop/mobile-backend/) for user management, leaderboard and game analytics.

## Installing the project
The project is open source and fully available to tweak, change, use, etc. To install the project on your machine, you simply need to download the git repository as shown below:

> Note: KiiBlocks depends on **[KiiToolkit](https://github.com/KiiPlatform/KiiToolkit-iOS)** which is included as a submodule. The code below will recursively clone the submodules included within the KiiBlocks project

    $ git clone --recursive https://github.com/KiiPlatform/KiiBlocks  
    

For a great tutorial about git submodules, check out [this page](http://git-scm.com/book/en/Git-Tools-Submodules)


## Video Tutorials
There is an ongoing video series dedicated to the development of this project, aimed to teach about SpriteKit, Kii Cloud and general iOS game development. If you're new to SpriteKit, start at the beginning - or jump around to what looks most relevant to you.

Each tutorial will have a tag in this Github project's **Releases** section so you can pull the exact code snapshot relevant to that tutorial without having to sift through the entire game. 

### Part 1: Getting started with SpriteKit
The first part in a video series for building an iOS game using SpriteKit and Kii Cloud. This installment will show how to create a SpriteKit project and test out the built-in physics engine.

> See the video here: [http://www.youtu.be/kpFwM8CZ10U](http://www.youtube.com/watch?v=kpFwM8CZ10U)

> Relevant code is under the tag **tutorial-1** located [here](https://github.com/KiiPlatform/KiiBlocks/releases/tag/tutorial-1)

### Part 2: Setting up the game board
The second part in a video series for building an iOS game using SpriteKit and Kii Cloud. This installment will show how to create the board for our game, with a number of blocks in a 2-dimensional grid interacting with one another.

> See the video here: [http://www.youtu.be/KyoEEt75ENQ](http://www.youtube.com/watch?v=KyoEEt75ENQ)

> Relevant code is under the tag **tutorial-2** located [here](https://github.com/KiiPlatform/KiiBlocks/releases/tag/tutorial-2)

### Part 3: User Interaction
The third part in a video series for building an iOS game using SpriteKit and Kii Cloud. This installment will show how to create user interaction with your game board - including some logic for the game to behave the way we want it to!

> See the video here: [http://www.youtu.be/pf-oykYjLZk](http://www.youtube.com/watch?v=pf-oykYjLZk)

> Relevant code is under the tag **tutorial-3** located [here](https://github.com/KiiPlatform/KiiBlocks/releases/tag/tutorial-3)

### Part 4: Scoring and Gamification
The fourth part in a video series for building an iOS game using SpriteKit and Kii Cloud. This installment will show how to implement scoring in our game and also a timer with proper game starts and finishes.

> See the video here: [http://www.youtu.be/n8oAWFDvfxM](http://www.youtube.com/watch?v=n8oAWFDvfxM)

> Relevant code is under the tag **tutorial-4** located [here](https://github.com/KiiPlatform/KiiBlocks/releases/tag/tutorial-4)

### Part 5: Add a leaderboard to your game
The fifth part in a video series for building an iOS game using SpriteKit and Kii Cloud. This installment will show how to implement a fully-functional global leaderboard to your game using [Kii Cloud](http://en.kii.com/develop/). Allow users to sign up, sign in, post and retrieve scores in a matter of minutes!

> See the video here: [http://youtu.be/bVeJCO-9WOU](http://youtu.be/bVeJCO-9WOU)

> Relevant code is under the tag **tutorial-5** located [here](https://github.com/KiiPlatform/KiiBlocks/releases/tag/tutorial-5)

## Who owns the code for KiiBlocks?
Developers at Kii are the main contributors, but it is completely open source under the [Apache 2.0 license](http://www.apache.org/licenses/LICENSE-2.0 "Apache 2.0") - so feel free to copy/change/modify as needed. We would love to see your contributions and ideas!


## What is Kii Cloud?
[Kii Cloud](http://en.kii.com/develop/ "Kii Cloud") is a Mobile-Backend-as-a-Service (MBaaS) which provides client SDKs for you to build a cloud-connected application without ever building or maintaining any servers or databases. Kii Cloud scales with your app and provides a reliable backend, allowing you to get your app up and running in a fraction of the time. Learn more at [http://kii.com](http://en.kii.com/develop/ "Kii Cloud")


## Issues Installing?
If you are having trouble installing the code from a tagged release - or are getting errors about files not being found - be sure that you have the KiiToolkit-iOS directory within the project (and that there are files in it).

**[KiiToolkit](https://github.com/KiiPlatform/KiiToolkit-iOS)** is included as a submodule to this project, and is required for a successful build. 

For a great tutorial about git submodules, check out [this page](http://git-scm.com/book/en/Git-Tools-Submodules)

